@@ -177,7 +177,19 @@ class EventsRuleToKinesisStreams(
         :summary: Constructs a new instance of the EventsRuleToKinesisStreams class.
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(EventsRuleToKinesisStreams.__init__)
+            def stub(
+                scope: aws_cdk.core.Construct,
+                id: builtins.str,
+                *,
+                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_stream_props: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = EventsRuleToKinesisStreamsProps(
@@ -257,7 +269,17 @@ class EventsRuleToKinesisStreamsProps:
         if isinstance(event_bus_props, dict):
             event_bus_props = aws_cdk.aws_events.EventBusProps(**event_bus_props)
         if __debug__:
-            type_hints = typing.get_type_hints(EventsRuleToKinesisStreamsProps.__init__)
+            def stub(
+                *,
+                event_rule_props: typing.Union[aws_cdk.aws_events.RuleProps, typing.Dict[str, typing.Any]],
+                create_cloud_watch_alarms: typing.Optional[builtins.bool] = None,
+                event_bus_props: typing.Optional[typing.Union[aws_cdk.aws_events.EventBusProps, typing.Dict[str, typing.Any]]] = None,
+                existing_event_bus_interface: typing.Optional[aws_cdk.aws_events.IEventBus] = None,
+                existing_stream_obj: typing.Optional[aws_cdk.aws_kinesis.Stream] = None,
+                kinesis_stream_props: typing.Any = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument event_rule_props", value=event_rule_props, expected_type=type_hints["event_rule_props"])
             check_type(argname="argument create_cloud_watch_alarms", value=create_cloud_watch_alarms, expected_type=type_hints["create_cloud_watch_alarms"])
             check_type(argname="argument event_bus_props", value=event_bus_props, expected_type=type_hints["event_bus_props"])
